function outfix(nomefile,data,names)

% Function OUTFIX writes output data of a model to an ASCII file
% readable by SIMLAB, when the output is a scalar value
%
% outfix(nomefile,data,names)
% 
% nomefile = name of the output file (CHAR)
% data     = matrix of the output data, output vars per column:
%            1st dimension RUN
%            2nd dimension (if more than 1 output is given) OUTPUT VARIABLE
% names    = char matrix with the factor names per rows

% The function has been developed by M. Ratto, European Commission, Joint Research Centre,
% Institute for the Protection and Security of The Citizen, Technological and Economic Risk Management,
% Applied Statistics, as a deliverable of the IMPACT project 
% (EC Fifth Framework Programme, SCA Project, IST-1999-11313, DG-INFSO).
%
% For more information, please contact marco.ratto@jrc.it
% 

if nargin<2
   disp(' ')
   disp('outfix(filename,data,names)')
   disp('This function writes output data of a model to an ASCII file')
   disp('readable by SIMLAB, when the output is a scalar value')
   disp(' ')
   disp('You must enter the file name and the data at least')
   disp('   filename = name (and path) of the output file (CHAR)')
   disp('   data     = matrix of the output data, output vars per column:')
   disp('              1st dimension RUN')
   disp('              2nd dimension OUTPUT VARIABLES')
   disp('   names    = char matrix with the factor names per rows (optional)')
   disp(' ')
   
else   
   fid=fopen(nomefile,'w');
   dim=size(data);
   if length(dim)<2, dim(2)=1; end,
   fprintf(fid,'%i\n',dim(2));
   if nargin==2,
      for j=1:dim(2), fprintf(fid,'%s\n',['out',num2str(j)]); end,         
   else         
      for j=1:dim(2), fprintf(fid,'%s\n',names(j,:)); end,         
   end   

   fprintf(fid,'time = no\n');
   fprintf(fid,'%i\n',dim(1));
   formato='%g \n';
   for i=2:dim(2), formato=['%g ',formato]; end,
   fprintf(fid, formato, data(:,:)');   

   fclose(fid); 
end