function outtime(nomefile,data,time,names)
% Function OUTTIME writes output data of a model to an ASCII file
% readable by SIMLAB, when the output is time dependent.
%
% outtime(nomefile,data,time,names)
%
% nomefile = name of the output file (CHAR)
% data     = matrix of the output data:
%            1st dimension TIME
%				 2nd dimension RUN
%            3rd dimension OUTPUT VARIABLE
% time     = time array
% names    = char matrix with the factor names per rows

% The routine has been developed by M. Ratto, European Commission, Joint Research Centre,
% Institute for the Protection and Security of The Citizen, Technological and Economic Risk Management,
% Applied Statistics, as a deliverable of the IMPACT project 
% (EC Fifth Framework Programme, SCA Project, IST-1999-11313, DG-INFSO).
%
% For more information, please contact marco.ratto@jrc.it
% 

if nargin<2
   disp(' ')
   disp('outtime(filename,data,time,names)')
   disp('This function writes output data of a model to an ASCII file')
   disp('readable by SIMLAB, when the output is time dependent')
   disp(' ')
   disp('You must enter the file name and the data at least')
   disp('   filename = name (and path) of the output file (CHAR)')
   disp('   data     = matrix of the output data, output vars per column:')
   disp('              1st dimension TIME')
   disp('              2nd dimension RUN')
   disp('              3rd dimension OUTPUT VARIABLES')
   disp('   time     = time array')
   disp('   names    = char matrix with the factor names per rows (optional)')
   disp(' ')
   
else
   fid=fopen(nomefile,'w');
   dim=size(data);
   if length(dim)<3, dim(3)=1; end,
   fprintf(fid,'%i\n',dim(3));
   if nargin<4,
      for j=1:dim(3), fprintf(fid,'%s\n',['out',num2str(j)]); end,         
   else         
      for j=1:dim(3), fprintf(fid,'%s\n',names(j,:)); end,         
   end   
   if nargin<3,
      time=[1:dim(1)];         
   end   
   
   time=reshape(time,1,dim(1));
   fprintf(fid,'time = yes\n');
   fprintf(fid,'%i\n',dim(2));
   for j=1:dim(2),
      fprintf(fid,'RUN %i\n',j-1);
      fprintf(fid,'%i\n',dim(1));
      formato='%g %g \n';
      for i=2:dim(3), formato=['%g ',formato]; end,
      fprintf(fid, formato, [time; squeeze(data(:,j,:))']);   
   end
   
   fclose(fid); 
   
   
end